@@ -136,7 +136,7 @@ rabbit_opts = [
                      'If you change this option, you must wipe the '
                      'RabbitMQ database.'),
     cfg.IntOpt('heartbeat_timeout_threshold',
-               default=0,
+               default=60,
                help="Number of seconds after which the Rabbit broker is "
                "considered down if heartbeat's keep-alive fails "
                "(0 disable the heartbeat). EXPERIMENTAL"),
@@ -452,8 +452,8 @@ class Connection(object):
                     adr, default_port=self.rabbit_port)
                 self._url += '%samqp://%s:%s@%s:%s/%s' % (
                     ";" if self._url else '',
-                    parse.quote(self.rabbit_userid),
-                    parse.quote(self.rabbit_password),
+                    parse.quote(self.rabbit_userid, ''),
+                    parse.quote(self.rabbit_password, ''),
                     self._parse_url_hostname(hostname), port,
                     virtual_host)
 
@@ -1047,8 +1047,8 @@ class Connection(object):
         """
 
         if not exchange.passive:
-            RuntimeError("_publish_and_retry_on_missing_exchange() must be "
-                         "called with an passive exchange.")
+            raise RuntimeError("_publish_and_retry_on_missing_exchange() must "
+                               "be called with an passive exchange.")
 
         # TODO(sileht): use @retrying
         # NOTE(sileht): no need to wait the application expect a response
@@ -1081,8 +1081,17 @@ class Connection(object):
                                  "retrying...") % {
                                      'exchange': exchange.name,
                                      'routing_key': routing_key})
-                    time.sleep(1)
+                    time.sleep(0.25)
                     continue
+                elif exc.code == 404:
+                    msg = _("The exchange %(exchange)s to send to "
+                            "%(routing_key)s still doesn't exist after "
+                            "%(duration)s sec abandonning...") % {
+                                'duration': duration,
+                                'exchange': exchange.name,
+                                'routing_key': routing_key}
+                    LOG.info(msg)
+                    raise rpc_amqp.AMQPDestinationNotFound(msg)
                 raise
 
     def direct_send(self, msg_id, msg):
